@@ -20,18 +20,18 @@
 
 // Header includes
 #include "scoresprite.h"
+#include "kfourinline_debug.h"
 
 // General includes
-#include <math.h>
+#include <cmath>
 
 // Qt includes
 #include <QFont>
 #include <QGraphicsScene>
 
 // KDE includes
-#include "kfourinline_debug.h"
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <KLocalizedString>
 
 // Constructor for the score sprite
@@ -106,7 +106,7 @@ void ScoreSprite::changeTheme()
   QPointF posBreak1   = config.readEntry("posBreak1", QPointF(1.0,1.0));
   QPointF posName0    = config.readEntry("posName0", QPointF(1.0,1.0));
   QPointF posName1    = config.readEntry("posName1", QPointF(1.0,1.0));
-  QPointF posAI       = config.readEntry("posAI", QPointF(1.0,1.0));
+  //QPointF posAI       = config.readEntry("posAI", QPointF(1.0,1.0));
 
   // Calculate proper font size
   double fontHeight = config.readEntry("fontHeight", 1.0);
